//
// Copyright (c) 2002
// Ronald Kevin Burton
//
// This material is provided "as is", with absolutely no warranty expressed
// or implied. This software is provided solely as part of ".NET Common Language
// Runtime Unleashed" to help illustrate concepts and principles described in 
// that book. Any use is at your own risk.
//
// Permission to use or copy this software for any purpose is hereby granted 
// without fee, provided the above notices are retained on all copies.
// Permission to modify the code and to distribute modified code is granted,
// provided the above notices are retained, and a notice that the code was
// modified is included with the above copyright notice.
//
// 
using System;
using System.Threading;
using System.Globalization;
using System.Diagnostics;

namespace CLRUnleashed.Remoting
{
	/// <summary>
	/// Summary description for TimeObject.
	/// </summary>
	public class TimeObject : MarshalByRefObject
	{
		public TimeObject()
		{
			Console.WriteLine("TimeObject activated");
			dateCount = 0;
			timeCount = 0;
		}
		public TimeObject(string culture)
		{
			Console.WriteLine("TimeObject({0}) activated", culture);
			
			try
			{
				ci = new CultureInfo(culture);
			}
			catch(ArgumentException e)
			{
				Debug.WriteLine(e);
				ci = null;
			}

			dateCount = 0;
			timeCount = 0;
		}
		public string Time
		{
			get
			{
				timeCount++;
				if(ci != null)
					Thread.CurrentThread.CurrentCulture = ci;
				return DateTime.Now.ToLongTimeString();
			}
		}
		public string Date
		{
			get
			{
				dateCount++;
				if(ci != null)
					Thread.CurrentThread.CurrentCulture = ci;
				return DateTime.Now.ToLongDateString();
			}
		}
		public int DateCount
		{
			get
			{
				return dateCount;
			}
		}
		public int TimeCount
		{
			get
			{
				return timeCount;
			}
		}

		private int dateCount;
		private int timeCount;
		private CultureInfo ci = null;
	}
}
