//
// Copyright (c) 2002
// Ronald Kevin Burton
//
// This material is provided "as is", with absolutely no warranty expressed
// or implied. This software is provided solely as part of ".NET Common Language
// Runtime Unleashed" to help illustrate concepts and principles described in 
// that book. Any use is at your own risk.
//
// Permission to use or copy this software for any purpose is hereby granted 
// without fee, provided the above notices are retained on all copies.
// Permission to modify the code and to distribute modified code is granted,
// provided the above notices are retained, and a notice that the code was
// modified is included with the above copyright notice.
//
// 
using System;
using System.IO;
using System.Text;
using System.Drawing;
using System.Collections;
using System.Diagnostics;
using System.ComponentModel;
using System.Windows.Forms;
using System.Runtime.Remoting;

using System.Runtime.Remoting.Lifetime;
using System.Runtime.Remoting.Channels;
using System.Runtime.Remoting.Channels.Http;

namespace CLRUnleashed.Remoting
{
	/// <summary>
	/// Summary description for TimeForm.
	/// </summary>
	public class TimeForm : System.Windows.Forms.Form
	{
		private System.ComponentModel.IContainer components;

		public TimeForm()
		{
			//
			// Required for Windows Form Designer support
			//
			InitializeComponent();

			string configFilename = "timeclient.exe.config";

			if(!Initialize(configFilename))
				return;

			timeService = new TimeObject();
			if (true == RemotingServices.IsTransparentProxy(timeService))
			{
				Debug.WriteLine("TimeObject activated on server");
				timer.Enabled = true;
			}
		}

		/// <summary>
		/// Clean up any resources being used.
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if (components != null) 
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}

		#region Windows Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
			this.components = new System.ComponentModel.Container();
			this.date = new System.Windows.Forms.TextBox();
			this.time = new System.Windows.Forms.TextBox();
			this.timer = new System.Windows.Forms.Timer(this.components);
			this.dateCount = new System.Windows.Forms.TextBox();
			this.timeCount = new System.Windows.Forms.TextBox();
			this.SuspendLayout();
			// 
			// date
			// 
			this.date.BackColor = System.Drawing.Color.Black;
			this.date.Font = new System.Drawing.Font("Trebuchet MS", 20.25F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((System.Byte)(0)));
			this.date.ForeColor = System.Drawing.Color.Lime;
			this.date.Location = new System.Drawing.Point(8, 32);
			this.date.Name = "date";
			this.date.Size = new System.Drawing.Size(400, 39);
			this.date.TabIndex = 0;
			this.date.Text = "";
			this.date.TextAlign = System.Windows.Forms.HorizontalAlignment.Center;
			// 
			// time
			// 
			this.time.BackColor = System.Drawing.Color.Black;
			this.time.Font = new System.Drawing.Font("Trebuchet MS", 20.25F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((System.Byte)(0)));
			this.time.ForeColor = System.Drawing.Color.Lime;
			this.time.Location = new System.Drawing.Point(8, 123);
			this.time.Name = "time";
			this.time.Size = new System.Drawing.Size(400, 39);
			this.time.TabIndex = 1;
			this.time.Text = "";
			this.time.TextAlign = System.Windows.Forms.HorizontalAlignment.Center;
			// 
			// timer
			// 
			this.timer.Interval = 5000;
			this.timer.Tick += new System.EventHandler(this.OnTick);
			// 
			// dateCount
			// 
			this.dateCount.Location = new System.Drawing.Point(184, 80);
			this.dateCount.Name = "dateCount";
			this.dateCount.Size = new System.Drawing.Size(56, 20);
			this.dateCount.TabIndex = 2;
			this.dateCount.Text = "";
			this.dateCount.TextAlign = System.Windows.Forms.HorizontalAlignment.Right;
			// 
			// timeCount
			// 
			this.timeCount.Location = new System.Drawing.Point(184, 176);
			this.timeCount.Name = "timeCount";
			this.timeCount.Size = new System.Drawing.Size(56, 20);
			this.timeCount.TabIndex = 3;
			this.timeCount.Text = "";
			this.timeCount.TextAlign = System.Windows.Forms.HorizontalAlignment.Right;
			// 
			// TimeForm
			// 
			this.AutoScaleBaseSize = new System.Drawing.Size(5, 13);
			this.ClientSize = new System.Drawing.Size(416, 222);
			this.Controls.AddRange(new System.Windows.Forms.Control[] {
																		  this.timeCount,
																		  this.dateCount,
																		  this.time,
																		  this.date});
			this.Name = "TimeForm";
			this.Text = "Remote Time";
			this.ResumeLayout(false);

		}
		#endregion

		/// <summary>
		/// The main entry point for the application.
		/// </summary>
		[STAThread]
		static void Main() 
		{
			Application.Run(new TimeForm());
		}

		private static bool Initialize(string configfile)
		{
			if(!File.Exists(configfile))
			{
				configfile = @"..\..\" + configfile;
				if(!File.Exists(configfile))
					return false;
			}
			RemotingConfiguration.Configure(configfile);
			return true;
		}

		private System.Windows.Forms.TextBox date;
		private System.Windows.Forms.TextBox time;
		private System.Windows.Forms.Timer timer;
		private System.Windows.Forms.TextBox dateCount;
		private System.Windows.Forms.TextBox timeCount;
		private TimeObject timeService = null;

		private void OnTick(object sender, System.EventArgs e)
		{
			if(timeService != null)
			{
				try
				{
					time.Text = timeService.Time;
					date.Text = timeService.Date;
					dateCount.Text = Convert.ToString(timeService.DateCount);
					timeCount.Text = Convert.ToString(timeService.TimeCount);
				}
				catch(Exception exception)
				{
					Debug.WriteLine(exception);
					timeService = null;
					timer.Enabled = false;
				}
			}
		}
	}
}
